@@ -11,7 +11,6 @@ from ebdtable2graph import (
     convert_table_to_digraph,
     convert_table_to_graph,
 )
-from ebdtable2graph.add_watermark import add_watermark
 from ebdtable2graph.graph_conversion import get_all_edges, get_all_nodes
 from ebdtable2graph.graphviz import convert_dot_to_svg_kroki, convert_graph_to_dot
 from ebdtable2graph.models import EbdGraph, EbdGraphMetaData
@@ -26,6 +25,7 @@ from ebdtable2graph.models.ebd_graph import (
     ToYesEdge,
 )
 from ebdtable2graph.models.ebd_table import EbdTable
+from ebdtable2graph.plantuml import GraphToComplexForPlantumlError
 from unittests.examples import table_e0003, table_e0015, table_e0025, table_e0401
 
 
@@ -184,10 +184,23 @@ class TestEbdTableModels:
         ) as svg_file:
             svg_file.write(svg_code)
 
-    def test_table_to_digraph_dot_with_watermark(self):
+    @pytest.mark.parametrize(
+        "add_background",
+        [
+            pytest.param(
+                True,
+            ),
+            pytest.param(
+                False,
+            ),
+        ],
+    )
+    def test_table_to_digraph_dot_with_watermark(self, add_background):
         ebd_graph = convert_table_to_graph(table_e0003)
         dot_code = convert_graph_to_dot(ebd_graph)
-        svg_code = convert_dot_to_svg_kroki(dot_code, add_watermark=False)  # Raises an error if conversion fails
+        svg_code = convert_dot_to_svg_kroki(
+            dot_code, add_watermark=False, add_background=False
+        )  # Raises an error if conversion fails
         os.makedirs(Path(__file__).parent / "output", exist_ok=True)
 
         with open(
@@ -197,22 +210,48 @@ class TestEbdTableModels:
         ) as svg_file:
             svg_file.write(svg_code)
 
-        svg_without_watermark = svg_code.encode("utf-8")
+        svg_code_with_watermark = convert_dot_to_svg_kroki(
+            dot_code, add_watermark=True, add_background=add_background
+        )  # Raises an error if conversion fails
 
-        svg_with_watermark = add_watermark(svg_without_watermark)
-
-        file_path2 = Path(__file__).parent / "output" / f"{ebd_graph.metadata.ebd_code}_with_watermark.dot.svg"
+        file_path2 = (
+            Path(__file__).parent
+            / "output"
+            / f"{ebd_graph.metadata.ebd_code}_with_watermark_background_is_{add_background}.dot.svg"
+        )
         with open(file_path2, "w", encoding="utf-8") as ebd_svg:
-            ebd_svg.write(svg_with_watermark.decode())
+            ebd_svg.write(svg_code_with_watermark)
+
+    def test_table_to_digraph_dot_with_background(self):
+        ebd_graph = convert_table_to_graph(table_e0003)
+        dot_code = convert_graph_to_dot(ebd_graph)
+        svg_code = convert_dot_to_svg_kroki(
+            dot_code, add_watermark=False, add_background=False
+        )  # Raises an error if conversion fails
+        os.makedirs(Path(__file__).parent / "output", exist_ok=True)
+
+        with open(
+            Path(__file__).parent / "output" / f"{ebd_graph.metadata.ebd_code}_without_watermark.dot.svg",
+            "w+",
+            encoding="utf-8",
+        ) as svg_file:
+            svg_file.write(svg_code)
+
+        svg_code = convert_dot_to_svg_kroki(
+            dot_code, add_watermark=False, add_background=True
+        )  # Raises an error if conversion fails
+
+        file_path2 = Path(__file__).parent / "output" / f"{ebd_graph.metadata.ebd_code}_with_background.dot.svg"
+        with open(file_path2, "w", encoding="utf-8") as ebd_svg:
+            ebd_svg.write(svg_code)
 
     def test_table_e0401_too_complex_for_plantuml(self):
         """
         Test the conversion pipeline for E_0401. In this case the plantuml conversion should fail because the graph is
         too complex for this implementation.
         """
-        with pytest.raises(AssertionError) as exc:
+        with pytest.raises(GraphToComplexForPlantumlError) as exc:
             _ = convert_graph_to_plantuml(convert_table_to_graph(table_e0401))
-
         assert "graph is too complex" in str(exc.value)
 
     @pytest.mark.parametrize(
